Struct snarkos_toolkit::dpc::transaction_kernel_builder::TransactionKernelBuilder[][src]

pub struct TransactionKernelBuilder { /* fields omitted */ }

Implementations

impl TransactionKernelBuilder[src]

pub fn new() -> Self[src]

pub fn add_input(
    self,
    private_key: PrivateKey,
    record: Record
) -> Result<Self, DPCError>
[src]

Returns a new transaction builder with the added transaction input. Otherwise, returns a DPCError.

pub fn add_output(
    self,
    recipient: Address,
    amount: u64
) -> Result<Self, DPCError>
[src]

Returns a new transaction builder with the added transaction output. Otherwise, returns a DPCError.

pub fn network_id(self, network_id: u8) -> Self[src]

Returns a new transaction builder with the updated network id.

pub fn memo(self, memo: [u8; 32]) -> Self[src]

Returns a new transaction builder with the updated network id.

pub fn build<R: Rng>(&self, rng: &mut R) -> Result<TransactionKernel, DPCError>[src]

Returns the transaction kernel (offline transaction) derived from the provided builder attributes.

Otherwise, returns DPCError.